@@ -29,7 +29,7 @@ from collections import namedtuple
 
 spine_itemref = namedtuple('SpineItemref', 'idref, linear')
 
-log = logging.getLogger('OPF')
+log = logging.getLogger('openaccess_epub.opf.opf')
 
 single_ccal_rights = '''This is an open-access article distributed under the \
 terms of the Creative Commons Attribution License, which permits unrestricted \
@@ -119,7 +119,7 @@ xmlns:oebpackage="http://openebook.org/namespaces/oeb-package/1.0/">
         Receives an instance of the Article class. This modifies the internal
         state of the OPF class to focus on the new article for the purposes of
         extracting metadata and content information.
-        
+
         In Collection Mode, the addition of new articles to the OPF class
         results in cumulative (in order of receipt) content. In Single Input
         Mode, the addition of a new article will erase any information from the
@@ -183,7 +183,7 @@ xmlns:oebpackage="http://openebook.org/namespaces/oeb-package/1.0/">
         """
         Sets internal methods to be publisher specific for the article at hand.
         """
-        if self.journal_doi == '10.1371':
+        if self.journal_doi == '10.1371':  # PLoS
             self.get_article_identifier = plos_dc_identifier
             self.get_article_language = plos_dc_language
             self.get_article_title = plos_dc_title
@@ -193,6 +193,16 @@ xmlns:oebpackage="http://openebook.org/namespaces/oeb-package/1.0/">
             self.get_article_description = plos_dc_description
             self.get_article_date = plos_dc_date
             self.get_article_subject = plos_dc_subject
+        elif self.journal_doi == '10.3389':  # Frontiers
+            self.get_article_identifier = frontiers_dc_identifier
+            self.get_article_language = frontiers_dc_language
+            self.get_article_title = frontiers_dc_title
+            self.get_article_creator = frontiers_dc_creator
+            self.get_article_contributor = frontiers_dc_contributor
+            self.get_article_publisher = frontiers_dc_publisher
+            self.get_article_description = frontiers_dc_description
+            self.get_article_date = frontiers_dc_date
+            self.get_article_subject = frontiers_dc_subject
         else:
             raise ValueError('This publisher, {0}, is not supported'.format(self.journal_doi))
 
@@ -236,7 +246,7 @@ xmlns:oebpackage="http://openebook.org/namespaces/oeb-package/1.0/">
         self.contributor = OrderedSet()  # 0+: Editors, reviewers
         self.publisher = OrderedSet()  # 0+: String for each publisher
         self.description = OrderedSet()  # 0+: Long description, often abstract text
-        self.subject = OrderedSet()  # 0+: 
+        self.subject = OrderedSet()  # 0+:
         self.date = OrderedSet()
 
         #These values are invariant, and will always be singular
@@ -266,7 +276,7 @@ xmlns:oebpackage="http://openebook.org/namespaces/oeb-package/1.0/">
                      'image/gif', 'tif': 'image/tif', 'pdf': 'application/pdf'}
         #Acquiring the current directory allows us to return there when complete
         #Thus avoiding problems relating call location, while allowing paths
-        #to be relative to the 
+        #to be relative to the
         current_dir = os.getcwd()
         os.chdir(self.location)
         for path, _subname, filenames in os.walk('OPS'):
@@ -410,8 +420,9 @@ xmlns:oebpackage="http://openebook.org/namespaces/oeb-package/1.0/">
                 return instring
             else:
                 prefix, suffix = instring.split(':')
-                return '{'+self.package.nsmap[prefix]+'}'+suffix
-        
+
+                return '{' + self.package.nsmap[prefix] + '}' + suffix
+
         if attrs is None:
             attrs = {}
         new_element = etree.SubElement(parent, ns_check(tag_name))
