@@ -12,7 +12,7 @@ import openaccess_epub.utils.element_methods as element_methods
 from lxml import etree
 import logging
 
-log = logging.getLogger('OPSMeta')
+log = logging.getLogger('openaccess_epub.ops.opsmeta')
 
 
 class OPSMeta(object):
@@ -116,3 +116,6 @@ class OPSMeta(object):
                 uri.attrib['href'] = xlink_href
             else:
                 uri.attrib['href'] = element_methods.all_text(uri)
+
+    def format_nlm_citation(self):
+        pass
